=======
stevens
=======

Overview
--------

Residue Classes

Installation
------------

To install stevens, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install stevens

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/stevens/#files>`_
* `Source <https://github.com/johannes-computer/stevens>`_

Credits
-------
- Author: Johannes
- Email: johannes-computer@mailfence.com

Thank you for using stevens!
